==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/ora_home_option/olap.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/settings'

newproperty(:olap) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Settings

  desc <<-DESC

      This resource allows you to manage(enable/disable) the OLAP option in an Oracle database home.

          ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
            ...
            olap                     => 'enabled',
            ...
          }

  DESC

  newvalues(:disabled, :enabled)
  data_type("Optional[Enum['disabled', 'enabled']]")

  to_translate_to_resource do |raw_resource|
    raw_resource['OLAP']
  end

  on_modify do
    flag = enabled? ? 'enable' : 'disable'
    oracle_home = resource.name
    ora_install_homes = Facter.value('ora_install_homes') || {}
    # TODO: get rid of settings dependency and rely on the facts, so we can also manage this property for homes that don't have a settings entry
    oh_settings_entry = configuration.find { |_db, settings| settings['oracle_home'] == oracle_home }
    os_user = ora_install_homes['product_version'].dig(oracle_home, 'os_user').nil? ? configuration_value_for(oh_settings_entry.first, 'os_user') : ora_install_homes['product_version'].dig(oracle_home, 'os_user')
    command = "su - #{os_user} -c \"export ORACLE_HOME=#{oracle_home}; #{oracle_home}/bin/chopt #{flag} olap\""
    options = { :failonfail => true, :combine => true }
    Puppet::Util::Execution.execute(command, options)
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end
end

==> enterprisemodules-ora_config-3.23.4.tar.gz: enterprisemodules-ora_config-3.23.4/lib/puppet/type/ora_home_option/olap.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/settings'

newproperty(:olap) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Settings

  desc <<-DESC

      This resource allows you to manage(enable/disable) the OLAP option in an Oracle database home.

          ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
            ...
            olap                     => 'enabled',
            ...
          }

  DESC

  newvalues(:disabled, :enabled)
  data_type("Optional[Enum['disabled', 'enabled']]")

  to_translate_to_resource do |raw_resource|
    raw_resource['OLAP']
  end

  on_modify do
    flag = enabled? ? 'enable' : 'disable'
    oracle_home = resource.name
    ora_install_homes = Facter.value('ora_install_homes') || {}
    # TODO: get rid of settings dependency and rely on the facts, so we can also manage this property for homes that don't have a settings entry
    oh_settings_entry = configuration.find { |_db, settings| settings['oracle_home'] == oracle_home }
    os_user = ora_install_homes['product_version'].dig(oracle_home, 'os_user').nil? ? configuration_value_for(oh_settings_entry.first, 'os_user') : ora_install_homes['product_version'].dig(oracle_home, 'os_user')
    command = "su - #{os_user} -c \"export ORACLE_HOME=#{oracle_home}; #{oracle_home}/bin/chopt #{flag} olap\""
    options = { :failonfail => true, :combine => true }
    Puppet::Util::Execution.execute(command, options)
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end
end
